@@ -671,7 +671,7 @@ bool ABI_Collab_Import::_import(const SessionPacket& packet, UT_sint32 iImportAd
 							//
 							// Get style of containing block
 							//
-							PL_StruxDocHandle sdh = NULL;
+							pf_Frag_Strux* sdh = NULL;
 							m_pDoc->getStruxOfTypeFromPosition(pos,PTX_Block,&sdh);
 							if(!sdh)
 							{
@@ -865,10 +865,10 @@ bool ABI_Collab_Import::_import(const SessionPacket& packet, UT_sint32 iImportAd
 					{
 						const Data_ChangeRecordSessionPacket* dp = static_cast<const Data_ChangeRecordSessionPacket*>( crp );
 						const char * szNameV = g_strdup(dp->getAttribute(PT_DATAITEM_ATTRIBUTE_NAME));
-						void * pHandle = NULL;
+						PD_DataItemHandle pHandle = NULL;
 						std::string sToken = dp->m_bTokenSet ? dp->m_sToken : "";
 						UT_ByteBuf * pBuf= new UT_ByteBuf();
-						UT_DEBUGMSG(("PXT_CreateDataItem: append image buffer @ 0x%p, %u bytes, sToken %s\n", &dp->m_vecData[0], dp->m_vecData.size(), sToken.c_str()));
+						UT_DEBUGMSG(("PXT_CreateDataItem: append image buffer @ 0x%p, %lu bytes, sToken %s\n", &dp->m_vecData[0], (long unsigned)dp->m_vecData.size(), sToken.c_str()));
 						pBuf->append(reinterpret_cast<const UT_Byte *>( &dp->m_vecData[0] ), dp->m_vecData.size() );
 						bool res = m_pDoc->createDataItem(szNameV,false,pBuf,sToken,&pHandle);
 						delete pBuf;
