@@ -40,6 +40,8 @@
 #include <ut_mbtowc.h>
 #include <ut_locale.h>
 
+#include <sstream>
+
 /**
  * Constructor
  * 
@@ -58,6 +60,8 @@ ODe_AbiDocListener::ODe_AbiDocListener (PD_Document* pDocument,
       m_bInHyperlink(false),
       m_bInSection(false),
       m_bInAnnotation(false),
+      m_bPendingAnnotationEnd(false),
+      m_currentAnnotationName(""),
       m_iInTable(0),
       m_iInCell(0),
       m_pDocument(pDocument),
@@ -82,7 +86,7 @@ ODe_AbiDocListener::~ODe_AbiDocListener() {
 /**
  * 
  */
-bool ODe_AbiDocListener::populate(PL_StruxFmtHandle /*sfh*/,
+bool ODe_AbiDocListener::populate(fl_ContainerLayout* /*sfh*/,
                                  const PX_ChangeRecord * pcr)
 {
     switch (pcr->getType()) {
@@ -189,6 +193,7 @@ bool ODe_AbiDocListener::populate(PL_StruxFmtHandle /*sfh*/,
                 {
                     _closeSpan();
                     _closeField();
+                    _endAnnotation(api);
                     return true;
                 }
 
@@ -237,9 +242,9 @@ bool ODe_AbiDocListener::populate(PL_StruxFmtHandle /*sfh*/,
 /**
  * 
  */
-bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle /*sdh*/,
+bool ODe_AbiDocListener::populateStrux(pf_Frag_Strux* /*sdh*/,
                                        const PX_ChangeRecord* pcr,
-                                       PL_StruxFmtHandle* psfh)
+                                       fl_ContainerLayout** psfh)
 {
     UT_return_val_if_fail(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux, false);
     bool returnVal = true;
@@ -344,11 +349,27 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle /*sdh*/,
 
     case PTX_SectionAnnotation:
         {
+//            UT_DEBUGMSG(("pos:%d\n", pcr->getPosition()));
             _closeSpan();
             _closeField();
             _closeBookmark(m_bookmarkName);
             _closeHyperlink();
-            _openAnnotation(api);
+            std::stringstream ss;
+            {
+                const PP_AttrProp* pAP;
+                bool ok;
+                ok = m_pDocument->getAttrProp (api, &pAP);
+                if (ok)
+                {
+                    const gchar* pValue = NULL;
+                    if(pAP->getAttribute(PT_ANNOTATION_NUMBER,pValue) && pValue)
+                        ss << pValue;
+                }
+            }
+            if( ss.str().empty() )
+                ss << "defd" << pcr->getPosition();
+            
+            _openAnnotation( api, ss.str() );
         }
         break;
 
@@ -495,7 +516,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle /*sdh*/,
 /**
  * 
  */
-bool ODe_AbiDocListener::change(PL_StruxFmtHandle /*sfh*/, const PX_ChangeRecord * /*pcr*/)
+bool ODe_AbiDocListener::change(fl_ContainerLayout* /*sfh*/, const PX_ChangeRecord * /*pcr*/)
 {
     UT_ASSERT_NOT_REACHED();
     return true;
@@ -505,13 +526,13 @@ bool ODe_AbiDocListener::change(PL_StruxFmtHandle /*sfh*/, const PX_ChangeRecord
 /**
  * 
  */
-bool ODe_AbiDocListener::insertStrux(PL_StruxFmtHandle /*sfh*/,
+bool ODe_AbiDocListener::insertStrux(fl_ContainerLayout* /*sfh*/,
 									 const PX_ChangeRecord * /*pcr*/,
-									 PL_StruxDocHandle /*sdh*/,
+									 pf_Frag_Strux* /*sdh*/,
 									 PL_ListenerId /*lid*/,
-									 void (* /*pfnBindHandles*/)(PL_StruxDocHandle sdhNew,
+									 void (* /*pfnBindHandles*/)(pf_Frag_Strux* sdhNew,
 																 PL_ListenerId lid,
-																 PL_StruxFmtHandle sfhNew))
+																 fl_ContainerLayout* sfhNew))
 {
     UT_ASSERT_NOT_REACHED();
     return true;
@@ -842,7 +863,8 @@ void ODe_AbiDocListener::_closeEndnote() {
 /**
  * 
  */
-void ODe_AbiDocListener::_openAnnotation(PT_AttrPropIndex api) {
+void ODe_AbiDocListener::_openAnnotation(PT_AttrPropIndex api, const std::string& defaultName)
+{
 
     if (m_bInAnnotation) {
         return;
@@ -856,8 +878,20 @@ void ODe_AbiDocListener::_openAnnotation(PT_AttrPropIndex api) {
         pAP = NULL;
     }
 
-    m_pCurrentImpl->openAnnotation(pAP);
+    std::string name = defaultName;
+    {
+        const gchar* pValue = NULL;
+        if(pAP->getAttribute("name",pValue) && pValue)
+        {
+            name = pValue;
+        }
+        UT_DEBUGMSG(("_openAnnotation() api:%d name:%s\n", api, name.c_str() ));
+    }
+    
+    m_pCurrentImpl->openAnnotation( pAP, name, m_pDocument );
     m_bInAnnotation = true;
+    m_bPendingAnnotationEnd = true;
+    m_currentAnnotationName = name;
     m_bInBlock = false;
 }
 
@@ -865,17 +899,45 @@ void ODe_AbiDocListener::_openAnnotation(PT_AttrPropIndex api) {
 /**
  * 
  */
-void ODe_AbiDocListener::_closeAnnotation() {
-
+void ODe_AbiDocListener::_closeAnnotation()
+{
     if (!m_bInAnnotation) {
         return;
     }
 
-    m_pCurrentImpl->closeAnnotation();
+    m_pCurrentImpl->closeAnnotation( m_currentAnnotationName );
     m_bInAnnotation = false;
     m_bInBlock = true;
 }
 
+void ODe_AbiDocListener::_endAnnotation( PT_AttrPropIndex api ) 
+{
+    std::string name = m_currentAnnotationName;
+
+    if(!m_bPendingAnnotationEnd)
+        return;
+    
+    m_bPendingAnnotationEnd = false;
+    m_currentAnnotationName = "";
+    const PP_AttrProp* pAP = NULL;
+    bool ok = false;
+
+    ok = m_pDocument->getAttrProp (api, &pAP);
+    if (!ok) {
+        pAP = NULL;
+    }
+    const gchar* pValue = NULL;
+    if(pAP->getAttribute("name",pValue) && pValue)
+    {
+        name = pValue;
+    }
+    
+    UT_DEBUGMSG(("_endAnnotation() api:%d name:%s\n", api, name.c_str() ));
+    m_pCurrentImpl->endAnnotation( name );
+}
+
+
+
 
 /**
  * 
@@ -1224,7 +1286,9 @@ const gchar* ODe_AbiDocListener::_getObjectKey(const PT_AttrPropIndex& api,
  * 
  */
 void ODe_AbiDocListener::_insertInlinedImage(PT_AttrPropIndex api) {
-    const gchar* pImageName;
+    std::string fullName;
+    std::string extension;
+	const gchar* pImageName;
     const PP_AttrProp* pAP;
     bool ok;
 
@@ -1235,8 +1299,10 @@ void ODe_AbiDocListener::_insertInlinedImage(PT_AttrPropIndex api) {
 
     pImageName = 
         _getObjectKey(api, static_cast<const gchar*>("dataid"));
+    m_pDocument->getDataItemFileExtension(pImageName, extension, true);
+    fullName = pImageName + extension;
 
-    m_pCurrentImpl->insertInlinedImage(pImageName, pAP);
+    m_pCurrentImpl->insertInlinedImage(fullName.c_str(), pAP);
 }
 
 
