@@ -1,22 +1,22 @@
 /* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
 
 /* AbiSource
- * 
+ *
  * Copyright (C) 2008 Firat Kiyak <firatkiyak@gmail.com>
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
 
@@ -76,7 +76,7 @@ public:
 	UT_Error startParagraph(int target);
 	UT_Error finishParagraph(int target);
 	UT_Error startText(int target);
-	UT_Error writeText(int target, const char* text);
+	UT_Error writeText(int target, const UT_UCS4Char* text);
 	UT_Error finishText(int target);
 	UT_Error startRun(int target);
 	UT_Error finishRun(int target);
@@ -195,12 +195,12 @@ public:
 
 protected:
     virtual UT_Error _writeDocument(void);
-    
+
 private:
 	PD_Document* m_pDoc;
 	GsfOutfile* root; //.docx file zip root
 	GsfOutfile* relsDir; // _rels
-	GsfOutfile* wordDir; // word 
+	GsfOutfile* wordDir; // word
 	GsfOutfile* wordRelsDir; // word/_rels
 	GsfOutfile* wordMediaDir; // word/media
 	GsfOutput* contentTypesStream; // [Content_Types].xml
