@@ -1,19 +1,19 @@
 /* AbiWord
  * Copyright (C) 2001-2002 Dom Lachowicz
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
 
@@ -33,9 +33,9 @@ public:
 	virtual ~GR_UnixImage();
 
 	virtual bool		convertToBuffer(UT_ByteBuf** ppBB) const;
-	virtual bool		convertFromBuffer(const UT_ByteBuf* pBB, 
-                                          const std::string & mimetype, 
-                                          UT_sint32 iDisplayWidth, 
+	virtual bool		convertFromBuffer(const UT_ByteBuf* pBB,
+                                          const std::string & mimetype,
+                                          UT_sint32 iDisplayWidth,
                                           UT_sint32 iDisplayHeight);
 	bool                saveToPNG(const char * szFile);
 	virtual bool hasAlpha (void) const;
@@ -47,7 +47,7 @@ public:
     virtual void        scaleImageTo(GR_Graphics * pG, const UT_Rect & rec);
     virtual bool isTransparentAt(UT_sint32 x, UT_sint32 y);
     void scale (UT_sint32 iDisplayWidth, UT_sint32 iDisplayHeight);
-	virtual void cairoSetSource(cairo_t *, double x, double y);
+	virtual void cairoSetSource(cairo_t *);
 protected:
 	virtual GR_UnixImage *makeSubimage(const std::string & n,
 											  UT_sint32 x, UT_sint32 y,
