@@ -24,6 +24,7 @@
 #include <signal.h>
 #include <string.h>
 #include <time.h>
+#include <memory>
 
 #include <glib.h>
 #include <gsf/gsf-utils.h>
@@ -141,7 +142,6 @@ XAP_App::~XAP_App()
 	// run thru and destroy all frames on our window list.
 	UT_VECTOR_PURGEALL(XAP_Frame *, m_vecFrames);
 	// when can have NULL pointers....
-	UT_VECTOR_SPARSEPURGEALL(GR_EmbedManager  *, m_vecEmbedManagers);
 
 	FREEP(m_szAbiSuiteLibDir);
 	DELETEP(m_pEMC);
@@ -247,27 +247,18 @@ XAP_Module * XAP_App::getPlugin(const char * szPluginName)
 /*!
  * Register an embeddable plugin with XAP_App
  */
-UT_sint32 XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed)
+bool XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed, const char *uid)
 {
-	 UT_return_val_if_fail( pEmbed, -1 );
+	 UT_return_val_if_fail( pEmbed, false );
 	 
-     UT_sint32 i=0;
-     bool bFound = false;
-     GR_EmbedManager * pCur = NULL;
-     for(i=0; !bFound && (i< m_vecEmbedManagers.getItemCount()); i++)
+	 if (uid == NULL)
+		uid = pEmbed->getObjectType();
+	 if (uid && *uid && m_mapEmbedManagers.find(uid) == m_mapEmbedManagers.end())
      {
-		 pCur =  m_vecEmbedManagers.getNthItem(i);
-		 if(pCur && (strcmp(pCur->getObjectType(),pEmbed->getObjectType()) == 0))
-		 {
-			 bFound = true;
-		 }
+		 m_mapEmbedManagers[uid] = pEmbed;
+		 return true;
      }
-     if(!bFound)
-     {
-		 m_vecEmbedManagers.addItem(pEmbed);
-		 return  m_vecEmbedManagers.getItemCount() - 1;
-     }
-     return -1;
+	return false;
 }
 
 
@@ -275,11 +266,14 @@ UT_sint32 XAP_App::registerEmbeddable(GR_EmbedManager * pEmbed)
  * UnRegister an embeddable plugin with XAP_App. The plugin itself is 
  * responsible for actually deleting the object.
  */
-bool XAP_App::unRegisterEmbeddable(UT_sint32 uid)
+bool XAP_App::unRegisterEmbeddable(const char *uid)
 {
-  if(uid < m_vecEmbedManagers.getItemCount())
+  if (uid == NULL || *uid == 0)
+    return false;
+  std::map<std::string, GR_EmbedManager *>::iterator i = m_mapEmbedManagers.find(uid);
+  if(i != m_mapEmbedManagers.end())
     {
-      m_vecEmbedManagers.setNthItem(uid,NULL,NULL);
+      m_mapEmbedManagers.erase(i);
       return true;
     }
   return false;
@@ -291,20 +285,10 @@ bool XAP_App::unRegisterEmbeddable(UT_sint32 uid)
  */
 GR_EmbedManager * XAP_App:: getEmbeddableManager(GR_Graphics * pG, const char * szObjectType)
 {
-     UT_sint32 i=0;
-     bool bFound = false;
      GR_EmbedManager * pCur = NULL;
-     for(i=0; !bFound && (i< m_vecEmbedManagers.getItemCount()); i++)
-     {
-       pCur =  m_vecEmbedManagers.getNthItem(i);
-       UT_DEBUGMSG(("Look at Manager for Object type %s requested %s strcmp %d strcmp %d \n",pCur->getObjectType(),szObjectType,strcmp(pCur->getObjectType(),szObjectType),strcmp(pCur->getObjectType(),szObjectType) ));
-
-       if(pCur && (strcmp(pCur->getObjectType(),szObjectType) == 0))
-       {
-	 bFound = true;
-       }
-     }
-     if(bFound)
+	 if (szObjectType && szObjectType != 0)
+       pCur =  m_mapEmbedManagers[szObjectType];
+     if(pCur != NULL)
      {
        UT_DEBUGMSG(("Found a plugin of type %s \n",pCur->getObjectType()));
        return pCur->create(pG);
@@ -808,12 +792,12 @@ XAP_Frame * XAP_App::getFrame(UT_sint32 ndx) const
 	return pFrame;
 }
 	
-UT_sint32 XAP_App::findFrame(XAP_Frame * pFrame)
+UT_sint32 XAP_App::findFrame(XAP_Frame * pFrame) const
 {
 	return m_vecFrames.findItem(pFrame);
 }
 	
-UT_sint32 XAP_App::findFrame(const char * szFilename)
+UT_sint32 XAP_App::findFrame(const char * szFilename) const
 {
 	if (!szFilename || !*szFilename)
 		return -1;
@@ -839,6 +823,14 @@ void XAP_App::_setAbiSuiteLibDir(const char * sz)
 	m_szAbiSuiteLibDir = g_strdup(sz);
 }
 
+// This should be removed at some time.
+void XAP_App::migrate (const char *oldName, const char *newName, const char *path) const
+{
+	UT_UNUSED(oldName);
+	UT_UNUSED(newName);
+	UT_UNUSED(path);
+}
+
 const char * XAP_App::getAbiSuiteLibDir() const
 {
 	return m_szAbiSuiteLibDir;
@@ -1211,7 +1203,7 @@ void XAP_App::setKbdLanguage(const char * pszLang)
 	}
 }
 
-void XAP_App::enumerateFrames(UT_Vector & v)
+void XAP_App::enumerateFrames(UT_Vector & v) const
 {
 	for(UT_sint32 i = 0; i < getFrameCount(); ++i)
 	{
@@ -1226,6 +1218,18 @@ void XAP_App::enumerateFrames(UT_Vector & v)
 	}
 }
 
+std::list< AD_Document* >
+XAP_App::getDocuments( const AD_Document * pExclude ) const
+{
+    UT_Vector t;
+    enumerateDocuments( t, pExclude );
+    std::list< AD_Document* > ret;
+    for( int i=0; i < t.size(); ++i )
+        ret.push_back( (AD_Document*)t[i] );
+    return ret;
+}
+
+
 /*!
     Enumerates currently open document associated with the
     application, excluding document pointed to by pExclude
@@ -1237,7 +1241,7 @@ void XAP_App::enumerateFrames(UT_Vector & v)
                     inside a document, it might be desirable to
                     exclude that document)
 */
-void XAP_App::enumerateDocuments(UT_Vector & v, const AD_Document * pExclude)
+void XAP_App::enumerateDocuments(UT_Vector & v, const AD_Document * pExclude) const
 {
 	UT_sint32 iIndx;
 
@@ -1689,3 +1693,12 @@ XAP_App::setNoGUI( bool v )
     m_bNoGUI = v;
 }
 
+std::string
+XAP_App::createUUIDString() const
+{
+    std::auto_ptr<UT_UUID> uuido(getUUIDGenerator()->createUUID());
+    std::string ret;
+	uuido->toString(ret);
+    return ret;
+}
+
