@@ -1,19 +1,20 @@
 /* AbiWord -- Embedded graphics for layout
  * Copyright (C) 1999 Matt Kimball
- * 
+ * Copyright (C) 2009 Hubert Figuiere
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
 
@@ -25,21 +26,26 @@
 #include "ut_types.h"
 
 //  An implementation of the FG_Graphic interface for raster files.  The
-//  internal file format happens to be PNG.
+//  internal file format happens to be PNG OR JPEG
 class ABI_EXPORT FG_GraphicRaster : public FG_Graphic
 {
 public:
-	static FG_Graphic*	createFromChangeRecord(const fl_ContainerLayout *pFL, 
+    enum Format {
+        PNG_FORMAT = 0,
+        JPEG_FORMAT
+    };
+	static FG_Graphic*	createFromChangeRecord(const fl_ContainerLayout *pFL,
 											   const PX_ChangeRecord_Object* pcro);
 	static FG_Graphic*	createFromStrux(const fl_ContainerLayout *pFL);
 
 	FG_GraphicRaster();
 	virtual ~FG_GraphicRaster();
 
-	virtual FGType		getType(void);
-	virtual FG_Graphic * clone(void);
-	virtual double		getWidth(void);
-	virtual double		getHeight(void);
+	virtual FGType		getType(void) const;
+    virtual const std::string & getMimeType() const;
+	virtual FG_Graphic * clone(void) const;
+	virtual double		getWidth(void) const;
+	virtual double		getHeight(void) const;
 	virtual const char * getDataId(void) const;
 	virtual const char * createDataItem(PD_Document *pDoc, const char * szName);
 	virtual GR_Image*	regenerateImage(GR_Graphics* pG);
@@ -49,21 +55,27 @@ public:
 
 	virtual UT_Error   	insertIntoDocument(PD_Document* pDoc, UT_uint32 res,
 										   UT_uint32 iPos, const char* szName);
-	virtual UT_Error   	insertAtStrux(PD_Document* pDoc, 
+	virtual UT_Error   	insertAtStrux(PD_Document* pDoc,
 									  UT_uint32 res,
 									  UT_uint32 iPos,
-									  PTStruxType iStruxType, 
+									  PTStruxType iStruxType,
 									  const char* szName);
 
 	bool				setRaster_PNG(const UT_ByteBuf* pBB);
-	const UT_ByteBuf*		getRaster_PNG(void) const;
+    bool                setRaster_JPEG(const UT_ByteBuf* pBB);
+	virtual const UT_ByteBuf*	getBuffer() const;
+    Format              getFormat() const
+    {
+        return m_format;
+    }
 
 	virtual const char * getWidthProp(void);
 	virtual const char * getHeightProp(void);
 
 protected:
-	const UT_ByteBuf* m_pbbPNG;
-	bool m_bOwnPNG;
+    Format            m_format;
+	const UT_ByteBuf* m_pbb;
+	bool              m_bOwnBuffer;
 
 	UT_sint32 m_iWidth, m_iHeight;
 	UT_sint32 m_iMaxW;
