@@ -43,7 +43,7 @@
 #include "fv_Selection.h"
 #include "fv_InlineImage.h"
 
-#ifdef TOOLKIT_GTK
+#ifdef TOOLKIT_GTK_ALL
 #include "fv_UnixVisualDrag.h"
 #include "fv_UnixFrameEdit.h"
 #include "fv_UnixInlineImage.h"
@@ -73,6 +73,7 @@ class fp_CellContainer;
 
 class FG_Graphic;
 
+class pf_Frag_Strux;
 class PD_Document;
 class PP_AttrProp;
 class PP_RevisionAttr;
@@ -90,6 +91,7 @@ class AP_LeftRulerInfo;
 class AP_TopRuler;
 class AP_LeftRuler;
 
+class AP_Dialog_Annotation;
 class AP_Dialog_SplitCells;
 
 class XAP_App;
@@ -115,8 +117,9 @@ typedef enum _AP_JumpTarget
 	AP_JUMPTARGET_PAGE, 			// beginning of page
 	AP_JUMPTARGET_LINE,
 	AP_JUMPTARGET_BOOKMARK,
-	AP_JUMPTARGET_PICTURE, // TODO
-    AP_JUMPTARGET_XMLID
+//	AP_JUMPTARGET_PICTURE, TODO
+    AP_JUMPTARGET_XMLID,
+    AP_JUMPTARGET_ANNOTATION
 } AP_JumpTarget;
 
 struct fv_ChangeState
@@ -216,7 +219,7 @@ class ABI_EXPORT FV_View_BubbleBlocker
     FV_View_BubbleBlocker( FV_View* pView = 0 );
     ~FV_View_BubbleBlocker();
     FV_View_BubbleBlocker& operator=( const FV_View_BubbleBlocker& r );
-    
+
 };
 
 class ABI_EXPORT FV_View : public AV_View
@@ -251,7 +254,7 @@ public:
 	UT_sint32       getFrameMargin(void) const;
 
 	virtual void focusChange(AV_Focus focus);
-	virtual bool    isActive(void);
+	virtual bool    isActive(void) const;
 
 	virtual void	setXScrollOffset(UT_sint32);
 	virtual void	setYScrollOffset(UT_sint32);
@@ -260,17 +263,17 @@ public:
 	virtual void	cmdHyperlinkJump(UT_sint32 xPos, UT_sint32 yPos);
 	void	        cmdHyperlinkJump(PT_DocPosition pos);
 	void			cmdHyperlinkCopyLocation(PT_DocPosition pos);
-	
+
 	virtual void	draw(const UT_Rect* pRect=static_cast<UT_Rect*>(NULL));
 	virtual void 	drawSelectionBox(UT_Rect & box, bool drawHandles);
-private: 
+private:
 	inline void 	_drawResizeHandle(UT_Rect & box);
     void getCmdInsertRangeVariables( PT_DocPosition& posStart,
                                      PT_DocPosition& posEnd,
                                      fl_BlockLayout*& pBL1,
                                      fl_BlockLayout*& pBL2 );
-    
-    
+
+
 public:
 	const PP_AttrProp * getAttrPropForPoint() const;
 
@@ -290,7 +293,7 @@ public:
 	UT_Error		cmdInsertHyperlink(const char* szName);
 	UT_Error		cmdInsertXMLID(const std::string& name);
 	UT_Error		cmdDeleteXMLID(const std::string& name);
-    
+
 	fp_Run *        getHyperLinkRun(PT_DocPosition pos);
 	UT_Error		cmdDeleteHyperlink();
 	bool                    cmdInsertMathML(const char * szFileName,
@@ -311,7 +314,7 @@ public:
 	virtual void	toggleCase(ToggleCase c);
 	virtual void	setPaperColor(const gchar * clr);
 
-	virtual bool    isDocumentPresent(void);
+	virtual bool    isDocumentPresent(void) const;
 	virtual void	cmdCopy(bool bToClipboard = true);
 	virtual void	cmdCut(void);
 	virtual void	cmdPaste(bool bHonorFormatting = true);
@@ -367,7 +370,7 @@ public:
 	fl_BlockLayout* getCurrentBlock(void) const;
 
 	void draw(int page, dg_DrawArgs* da);
-	
+
 
 	// TODO some of these functions should move into protected
 
@@ -429,7 +432,7 @@ public:
 	bool	resetCharFormat(bool bAll);
 	bool	getCharFormat(const gchar *** properties,bool bExpandStyles=true) const;
 	bool	getCharFormat(const gchar *** properties,bool bExpandStyles, PT_DocPosition posStart) const;
-	fl_BlockLayout * getBlockFromSDH(PL_StruxDocHandle sdh);
+	fl_BlockLayout * getBlockFromSDH(pf_Frag_Strux* sdh);
 	bool	setStyle(const gchar * style, bool bDontGeneralUpdate=false);
 	bool	setStyleAtPos(const gchar * style, PT_DocPosition posStart, PT_DocPosition posEnd, bool bDontGeneralUpdate=false);
 	bool    isNumberedHeadingHere(fl_BlockLayout * pBlock) const;
@@ -451,6 +454,7 @@ public:
 	// ----------------------
 	bool			isLeftMargin(UT_sint32 xPos, UT_sint32 yPos) const;
     void            selectRange( PT_DocPosition start, PT_DocPosition end );
+    void            selectRange( const std::pair< PT_DocPosition, PT_DocPosition >& range );
 	void			cmdSelect(UT_sint32 xPos, UT_sint32 yPos, FV_DocPos dpBeg, FV_DocPos dpEnd);
 	void			cmdSelectTOC(UT_sint32 xPos, UT_sint32 yPos);
 	bool            isTOCSelected(void) const;
@@ -478,6 +482,7 @@ public:
 	void			extSelToXY(UT_sint32 xPos, UT_sint32 yPos, bool bDrag);
 	void			extSelToXYword(UT_sint32 xPos, UT_sint32 yPos, bool bDrag);
 	void			extSelTo(FV_DocPos dp);
+	void			swapSelectionOrientation(void);
 
 #ifdef ENABLE_SPELL
 	SpellChecker * getDictForSelection () const;
@@ -527,16 +532,21 @@ public:
 	void            btn1Frame(UT_sint32 x, UT_sint32 y);
 	void            dragFrame(UT_sint32 x, UT_sint32 y);
 	void            releaseFrame(UT_sint32 x, UT_sint32 y);
-	bool            isInFrame(PT_DocPosition pos);
+	bool            isInFrame(PT_DocPosition pos) const;
 	void            deleteFrame(void);
-	void            cutFrame(void);
+	void            copyFrame(bool b_keepFrame = true);
 	void            selectFrame(void);
-	fl_FrameLayout * getFrameLayout(PT_DocPosition pos);
-	fl_FrameLayout * getFrameLayout(void);
+	bool            isFrameSelected(void) const;
+	fl_FrameLayout * getFrameLayout(PT_DocPosition pos) const;
+	fl_FrameLayout * getFrameLayout(void) const;
 	void            setFrameFormat(const gchar ** props);
-	void            setFrameFormat(const gchar ** attribs, const gchar ** props);
-	void            setFrameFormat(const gchar ** props,FG_Graphic * pFG, const std::string & dataID);
-	void            convertInLineToPositioned(PT_DocPosition pos, 
+	void            setFrameFormat(const gchar ** attribs, const gchar ** props,
+								   fl_BlockLayout * pNewBL = NULL);
+	void            setFrameFormat(const gchar ** props,FG_Graphic * pFG, const std::string & dataID,
+								   fl_BlockLayout * pNewBL = NULL);
+	bool            getFrameStrings_view(UT_sint32 x, UT_sint32 y,fv_FrameStrings & FrameStrings,
+										 fl_BlockLayout ** pCloseBL,fp_Page ** ppPage);
+	void            convertInLineToPositioned(PT_DocPosition pos,
 											const gchar ** attribs);
 
 	bool            convertPositionedToInLine(fl_FrameLayout * pFrame);
@@ -564,16 +574,16 @@ public:
 // ----------------------
 // Stuff for edittable Headers/Footers
 //
-	bool                isInHdrFtr(PT_DocPosition pos);
+	bool                isInHdrFtr(PT_DocPosition pos) const;
 	void				setHdrFtrEdit(fl_HdrFtrShadow * pShadow);
 	void				clearHdrFtrEdit(void);
-	bool				isHdrFtrEdit(void);
-	fl_HdrFtrShadow *	getEditShadow(void);
+	bool				isHdrFtrEdit(void) const;
+	fl_HdrFtrShadow *	getEditShadow(void) const;
 	void				rememberCurrentPosition(void);
-	PT_DocPosition		getSavedPosition(void);
+	PT_DocPosition		getSavedPosition(void) const;
 	void				clearSavedPosition(void);
 	void				markSavedPositionAsNeeded(void);
-	bool				needSavedPosition(void);
+	bool				needSavedPosition(void) const;
 	void				insertHeaderFooter(HdrFtrType hfType);
 	bool				insertHeaderFooter(const gchar ** props, HdrFtrType hfType, fl_DocSectionLayout * pDSL=NULL);
 
@@ -581,8 +591,8 @@ public:
 	void				cmdEditFooter(void);
 
 	void                cmdRemoveHdrFtr(bool isHeader);
-	bool                isFooterOnPage(void);
-	bool                isHeaderOnPage(void);
+	bool                isFooterOnPage(void) const;
+	bool                isHeaderOnPage(void) const;
 
 	void                SetupSavePieceTableState(void);
 	void                RestoreSavedPieceTableState(void);
@@ -597,26 +607,27 @@ public:
 //
 	bool	            insertFootnote(bool bFootnote);
 	bool	            insertFootnoteSection(bool bFootnote,const gchar * enpid);
-	bool                isInFootnote(PT_DocPosition pos);
-	bool                isInFootnote(void);
-	bool                isInEndnote(PT_DocPosition pos);
-	bool                isInEndnote(void);
-	bool                isInAnnotation(PT_DocPosition pos);
-	bool                isInAnnotation(void);
-	fl_FootnoteLayout * getClosestFootnote(PT_DocPosition pos);
-	fl_EndnoteLayout *  getClosestEndnote(PT_DocPosition pos);
-	fl_AnnotationLayout *  getClosestAnnotation(PT_DocPosition pos);
-	UT_sint32           getEmbedDepth(PT_DocPosition pos);
+	bool                isInFootnote(PT_DocPosition pos) const;
+	bool                isInFootnote(void) const;
+	bool                isInEndnote(PT_DocPosition pos) const;
+	bool                isInEndnote(void) const;
+	bool                isInAnnotation(PT_DocPosition pos) const;
+	bool                isInAnnotation(void) const;
+	fl_FootnoteLayout * getClosestFootnote(PT_DocPosition pos) const;
+	fl_EndnoteLayout *  getClosestEndnote(PT_DocPosition pos) const;
+	fl_AnnotationLayout *  getClosestAnnotation(PT_DocPosition pos) const;
+	UT_sint32           getEmbedDepth(PT_DocPosition pos) const;
 	//
 	// ----------------------------------
 	// Stuff for Annotaions
-	//	
+	//
 	bool				insertAnnotation(UT_sint32 iAnnotation,
 										 const std::string & sDescr,
 										 const std::string & sAuthor,
 										 const std::string & sTitle,
 										 bool bReplace);
 	bool                getAnnotationText(UT_uint32 iAnnotation, std::string & sText) const;
+    std::string         getAnnotationText(UT_uint32 iAnnotation) const;
 	bool                setAnnotationText(UT_uint32 iAnnotation, const std::string & sText);
 	bool                setAnnotationText(UT_uint32 iAnnotation, const std::string & sText,
                                           const std::string & sAuthor, const std::string & sTitle);
@@ -624,8 +635,10 @@ public:
     bool                setAnnotationRichText(UT_uint32 iAnnotation, const std::string & sRTF);
 	// TODO getters and setters to implement/change/add as judged necessary
 	bool                getAnnotationTitle(UT_uint32 iAnnotation, std::string & sTitle) const;
+    std::string         getAnnotationTitle(UT_uint32 iAnnotation) const;
 	bool                setAnnotationTitle(UT_uint32 iAnnotation, const std::string & sTitle);
 	bool                getAnnotationAuthor(UT_uint32 iAnnotation, std::string & sAuthor) const;
+    std::string         getAnnotationAuthor(UT_uint32 iAnnotation) const;
 	bool                setAnnotationAuthor(UT_uint32 iAnnotation, const std::string & sAuthor);
 
 	bool                isAnnotationPreviewActive(void) const { return m_bAnnotationPreviewActive;}
@@ -634,8 +647,10 @@ public:
 	void				setActivePreviewAnnotationID(UT_uint32 iID) { m_iAnnPviewID = iID;}
 	void				killAnnotationPreview();
 	bool				cmdEditAnnotationWithDialog(UT_uint32 aID);
+	fl_AnnotationLayout * insertAnnotationDescription(UT_uint32 aID, AP_Dialog_Annotation *pDialog);
 	fl_AnnotationLayout * getAnnotationLayout(UT_uint32 iAnnotation) const;
 	bool                selectAnnotation(fl_AnnotationLayout * pAL);
+	UT_uint32           countAnnotations(void) const;
 
     FV_View_BubbleBlocker getBubbleBlocker();
     bool                  bubblesAreBlocked() const;
@@ -668,7 +683,7 @@ public:
 
 	bool			findNext(bool& bDoneEntireDocument);
 	bool			findNext(const UT_UCSChar* pFind, bool& bDoneEntireDocument);
-	
+
 	UT_uint32*		_computeFindPrefix(const UT_UCSChar* pFind);
 
 	bool			_findNext(UT_uint32* pPrefix,
@@ -713,7 +728,7 @@ public:
     void                removeCaret(const std::string& sCaretID);
 	void                addCaret(PT_DocPosition docPos,UT_sint32 iAuthorId);
 	void                setPointRemote(PT_DocPosition docPos);
-	void                updateCarets(PT_DocPosition docPos, UT_sint32 iLen);   
+	void                updateCarets(PT_DocPosition docPos, UT_sint32 iLen);
 	void		    fixInsertionPointCoords(void);
 
 // -----------------------
@@ -733,7 +748,7 @@ public:
 
 	UT_uint32           getTabToggleAreaWidth() const;
 	UT_sint32           getNormalModeXOffset() const;
-	
+
 	void				setScreenUpdateOnGeneralUpdate( bool bDoit)
 		{m_bDontUpdateScreenOnGeneralUpdate = !bDoit;}
 	bool				shouldScreenUpdateOnGeneralUpdate(void) const
@@ -750,7 +765,7 @@ public:
 	bool                isShowRevisions() const {return m_bShowRevisions;}
 	void                toggleShowRevisions();
 	void                setShowRevisions(bool bShow);
-	
+
 	void                cmdSetRevisionLevel(UT_uint32 i);
 	UT_uint32           getRevisionLevel()const;
 	void                setRevisionLevel(UT_uint32 i);
@@ -763,23 +778,22 @@ public:
 	void                _fixInsertionPointAfterRevision();
 	bool                _makePointLegal(void);
   public:
-  
+
 	/* Table related functions */
-	bool                isPointLegal(PT_DocPosition pos);
-	bool                isPointLegal(void);
+	bool                isPointLegal(PT_DocPosition pos) const;
+	bool                isPointLegal(void) const;
 	bool				isInTable() const;
 	fl_TableLayout *    getTableAtPos(PT_DocPosition) const;
 	bool				isInTable(PT_DocPosition pos) const;
-	bool				isInTableForSure(PT_DocPosition pos) const;
 	bool                cmdAutoSizeCols(void);
 	bool                cmdTextToTable(bool bIgnoreSpaces);
 	bool                cmdAutoSizeRows(void);
 	bool                cmdAdvanceNextPrevCell(bool bGoNext);
 	fp_CellContainer *  getCellAtPos(PT_DocPosition pos) const;
-	PT_DocPosition      findCellPosAt(PT_DocPosition posTable, UT_sint32 row, UT_sint32 col);
+	PT_DocPosition      findCellPosAt(PT_DocPosition posTable, UT_sint32 row, UT_sint32 col) const;
 	bool                _deleteCellAt(PT_DocPosition posTable,UT_sint32 row, UT_sint32 col);
 	bool                _restoreCellParams(PT_DocPosition posTable, UT_sint32 iLineWidth);
-	UT_sint32           _changeCellParams(PT_DocPosition posTable,PL_StruxDocHandle tableSDH );
+	UT_sint32           _changeCellParams(PT_DocPosition posTable,pf_Frag_Strux* tableSDH );
 	bool                deleteCellAt(PT_DocPosition posTable,UT_sint32 row, UT_sint32 col);
 	bool                cmdDeleteCell(PT_DocPosition pos);
 	bool                cmdDeleteCol(PT_DocPosition pos);
@@ -794,32 +808,32 @@ public:
 	bool                cmdTableToText(PT_DocPosition posSource,UT_sint32 iSepType);
 
 	bool                _MergeCells( PT_DocPosition posDestination,PT_DocPosition posSource, bool bBefore);
-	bool                getCellParams(PT_DocPosition posCol, UT_sint32 *iLeft, 
+	bool                getCellParams(PT_DocPosition posCol, UT_sint32 *iLeft,
 									  UT_sint32 *iRight,UT_sint32 *iTop, UT_sint32 *iBot) const;
 	bool				getCellLineStyle(PT_DocPosition posCell, UT_sint32 * pLeft, UT_sint32 * pRight,
 										 UT_sint32 * pTop, UT_sint32 * pBot) const;
 	bool				setCellFormat(const gchar * properties[], FormatTable applyTo, FG_Graphic * pFG, UT_String & sDataID);
-	bool				getCellProperty(const gchar * szPropName, gchar * &szPropValue) const;
+	bool				getCellProperty(PT_DocPosition pos, const gchar * szPropName, gchar * &szPropValue) const;
 	bool	            setTableFormat(const gchar * properties[]);
 	bool	            setTableFormat(PT_DocPosition pos,const gchar * properties[]);
 	bool                getCellFormat(PT_DocPosition pos, UT_String & sCellProps) const;
 
-	UT_Error            cmdInsertTable(UT_sint32 numRows, UT_sint32 numCols, 
+	UT_Error            cmdInsertTable(UT_sint32 numRows, UT_sint32 numCols,
 									   const gchar * pPropsArray[]);
-	bool                _changeCellTo(PT_DocPosition posTable,UT_sint32 rowOld, 
+	bool                _changeCellTo(PT_DocPosition posTable,UT_sint32 rowOld,
 									  UT_sint32 colOld, UT_sint32 left, UT_sint32 right,
 									  UT_sint32 top, UT_sint32 bot);
-	bool                changeCellTo(PT_DocPosition posTable,UT_sint32 rowOld, 
+	bool                changeCellTo(PT_DocPosition posTable,UT_sint32 rowOld,
 									 UT_sint32 colOld, UT_sint32 left, UT_sint32 right,
 		                             UT_sint32 top, UT_sint32 bot);
-	bool                _insertCellAfter(PT_DocPosition posTable, UT_sint32 row, 
+	bool                _insertCellAfter(PT_DocPosition posTable, UT_sint32 row,
 										 UT_sint32 col,UT_sint32 left,UT_sint32 right,
 										 UT_sint32 top, UT_sint32 bot);
-	bool                _insertCellBefore(PT_DocPosition posTable, UT_sint32 row, 
+	bool                _insertCellBefore(PT_DocPosition posTable, UT_sint32 row,
 										  UT_sint32 col, UT_sint32 left, UT_sint32 right,
 										  UT_sint32 top, UT_sint32 bot);
 	void				_generalUpdate(void);
-	
+
 	UT_RGBColor			getColorShowPara(void) const { return m_colorShowPara; }
 #ifdef ENABLE_SPELL
 	UT_RGBColor			getColorSquiggle(FL_SQUIGGLE_TYPE iSquiggleType) const;
@@ -831,16 +845,16 @@ public:
 	UT_RGBColor			getColorImage(void) const { return m_colorImage; }
 	UT_RGBColor			getColorImageResize(void) const { return m_colorImageResize; }
 	UT_RGBColor			getColorHyperLink(void) const { return m_colorHyperLink; }
-	UT_RGBColor			getColorAnnotation(const fp_Run * pRun) const; 
-	UT_RGBColor			getColorAnnotation(fp_Page * pPage,UT_uint32 pid) const; 
-	UT_RGBColor			getColorRDFAnchor(const fp_Run * pRun) const; 
-	UT_RGBColor			getColorRevisions(int rev) const { 
+	UT_RGBColor			getColorAnnotation(const fp_Run * pRun) const;
+	UT_RGBColor			getColorAnnotation(fp_Page * pPage,UT_uint32 pid) const;
+	UT_RGBColor			getColorRDFAnchor(const fp_Run * pRun) const;
+	UT_RGBColor			getColorRevisions(int rev) const {
 		if ((rev < 0) || (rev > 9)) rev = 9;
 		return m_colorRevisions[rev]; }
 	UT_RGBColor			getColorHdrFtr(void) const { return m_colorHdrFtr; }
 	UT_RGBColor			getColorColumnLine(void) const { return m_colorColumnLine; }
 
-	void                getVisibleDocumentPagesAndRectangles(UT_GenericVector<UT_Rect*> &vRect, 
+	void                getVisibleDocumentPagesAndRectangles(UT_GenericVector<UT_Rect*> &vRect,
 															 UT_GenericVector<fp_Page*> &vPages) const;
 
 	//
@@ -853,19 +867,19 @@ public:
 //
 // Table resizing
 //
-	void                setDragTableLine(bool bSet) 
+	void                setDragTableLine(bool bSet)
                         { m_bDragTableLine = bSet;}
-	bool                getDragTableLine(void) const 
+	bool                getDragTableLine(void) const
 		                { return m_bDragTableLine;}
-	void                setTopRuler(AP_TopRuler * pRuler) 
+	void                setTopRuler(AP_TopRuler * pRuler)
                         { m_pTopRuler = pRuler;}
-	AP_TopRuler *       getTopRuler(void) const 
+	AP_TopRuler *       getTopRuler(void) const
 		                { return m_pTopRuler;}
-	void                setLeftRuler(AP_LeftRuler * pRuler) 
+	void                setLeftRuler(AP_LeftRuler * pRuler)
                         { m_pLeftRuler = pRuler;}
-	AP_LeftRuler *       getLeftRuler(void) const 
+	AP_LeftRuler *       getLeftRuler(void) const
 		                { return m_pLeftRuler;}
-	
+
 
 	const gchar **   getViewPersistentProps() const;
 	FV_BIDI_Order	    getBidiOrder()const {return m_eBidiOrder;}
@@ -876,7 +890,7 @@ public:
         bool                isMathLoaded(void) const;
 	bool                isGrammarLoaded(void) const;
 	// --
-	
+
 	UT_uint32			getNumHorizPages(void) const; //////////////////////////////////
 	void				calculateNumHorizPages(void);
 	UT_uint32			getMaxHeight(UT_uint32 iRow) const;
@@ -884,11 +898,11 @@ public:
 	UT_uint32			getWidthPagesInRow(fp_Page *page) const;
 	UT_uint32			getHorizPageSpacing(void) const;
 	bool				rtlPages(void) const;
-	
+
 protected:
 	void				_saveAndNotifyPieceTableChange(void);
 	void				_restorePieceTableState(void);
-	
+
 	void				_draw(UT_sint32, UT_sint32, UT_sint32, UT_sint32, bool bDirtyRunsOnly, bool bClip=false);
 
 	void				_drawBetweenPositions(PT_DocPosition left, PT_DocPosition right);
@@ -898,7 +912,7 @@ protected:
 	void				_moveInsPtNextPrevPage(bool bNext);
 	void				_moveInsPtNextPrevScreen(bool bNext);
 	void				_moveInsPtNextPrevLine(bool bNext);
-	fp_Line *           _getNextLineInDoc(fp_Container * pCon);
+	fp_Line *           _getNextLineInDoc(fp_Container * pCon) const;
 	fp_Page *			_getCurrentPage(void) const;
 	void				_moveInsPtNthPage(UT_sint32 n);
 	void				_moveInsPtToPage(fp_Page *page);
@@ -924,8 +938,8 @@ protected:
 									  UT_sint32 yPos,
 									  UT_sint32& xClick,
 									  UT_sint32& yClick) const;
-	bool                _insertField(const char* szName, 
-									 const gchar ** extra_attrs = NULL, 
+	bool                _insertField(const char* szName,
+									 const gchar ** extra_attrs = NULL,
 									 const gchar ** extra_props = NULL);
 	void				_moveToSelectionEnd(bool bForward);
 	void				_eraseSelection(void);
@@ -942,7 +956,6 @@ protected:
 	void				_fixAllInsertionPointCoords(void) const;
 
 	void				_drawSelection();
-	void				_swapSelectionOrientation(void);
 	void				_extSel(UT_uint32 iOldPoint);
 	void				_extSelToPos(PT_DocPosition pos);
 	UT_Error			_insertGraphic(FG_Graphic*, const char*);
@@ -964,14 +977,14 @@ protected:
 #ifdef ENABLE_SPELL
 	void				_checkPendingWordForSpell(void);
 #endif
-	
+
 	bool				_isSpaceBefore(PT_DocPosition pos) const;
 	void				_removeThisHdrFtr(fl_HdrFtrSectionLayout * pHdrFtr);
 	void 				_cmdEditHdrFtr(HdrFtrType hfType);
 
 	UT_Error			_deleteBookmark(const char* szName, bool bSignal, PT_DocPosition * pos1 = NULL, PT_DocPosition * pos2 = NULL);
 	UT_Error			_deleteHyperlink(PT_DocPosition &i, bool bSignal);
-    
+
 	UT_Error			_deleteXMLID( const std::string& xmlid, bool bSignal, PT_DocPosition& posStart, PT_DocPosition& posEnd );
 	UT_Error			_deleteXMLID( const std::string& xmlid, bool bSignal );
 	fp_HyperlinkRun *   _getHyperlinkInRange(PT_DocPosition &posStart,
@@ -983,7 +996,7 @@ protected:
 
     void                incremenetBubbleBlockerCount();
     void                decremenetBubbleBlockerCount();
-    
+
 private:
 
 	UT_uint32			m_iNumHorizPages; /////////////////////////////////////////////////
@@ -1083,7 +1096,7 @@ private:
 	UT_Rect				m_dragImageRect;
 	UT_sint32			m_ixDragOrigin;
 	UT_sint32			m_iyDragOrigin;
-	
+
 	// default color values
 	UT_RGBColor			m_colorShowPara;
 	UT_RGBColor			m_colorSpellSquiggle;
@@ -1114,12 +1127,12 @@ private:
 	mutable fv_PropCache        m_BlockProps;
 	mutable fv_PropCache        m_SecProps;
 	AV_ListenerId       m_CaretListID;
-#ifdef TOOLKIT_GTK
+#ifdef TOOLKIT_GTK_ALL
 	FV_UnixFrameEdit    m_FrameEdit;
 #else
 	FV_FrameEdit        m_FrameEdit;
 #endif
-#ifdef TOOLKIT_GTK
+#ifdef TOOLKIT_GTK_ALL
 	FV_UnixVisualDrag   m_VisualDragText;
 #else
 	FV_VisualDragText   m_VisualDragText;
@@ -1132,7 +1145,7 @@ private:
 	bool                m_bDontNotifyListeners;
 	UT_ByteBuf *        m_pLocalBuf;
 	UT_sint32           m_iGrabCell;
-#ifdef TOOLKIT_GTK
+#ifdef TOOLKIT_GTK_ALL
 	FV_UnixVisualInlineImage  m_InlineImage;
 #else
 	FV_VisualInlineImage  m_InlineImage;
