@@ -34,8 +34,6 @@
 #include <sstream>
 #include <set>
 #include <iostream>
-using std::cerr;
-using std::endl;
 using std::make_pair;
 
 #ifdef WITH_REDLAND
@@ -84,15 +82,16 @@ librdf_statement* toRedland( const PD_RDFStatement& st )
 }
 
 
+#ifdef DEBUG
 static std::string tostr( librdf_statement* statement )
 {
     std::stringstream ss;
-    ss << "  subj:" << tostr( librdf_statement_get_subject( statement ) ) << endl;
-    ss << "  pred:" << tostr( librdf_statement_get_predicate( statement ) ) << endl;
-    ss << "   obj:" << tostr( librdf_statement_get_object( statement ) ) << endl;
+    ss << "  subj:" << tostr( librdf_statement_get_subject( statement ) ) << std::endl;
+    ss << "  pred:" << tostr( librdf_statement_get_predicate( statement ) ) << std::endl;
+    ss << "   obj:" << tostr( librdf_statement_get_object( statement ) ) << std::endl;
     return ss.str();
 }
-
+#endif
 
 
 /********************************************************************************/
@@ -103,27 +102,27 @@ static std::string tostr( librdf_statement* statement )
 
 struct abiwordContext
 {
-    librdf_storage*   storage;
+    librdf_storage*   m_storage;
     PD_RDFModelHandle m_model;
-    int x;
+    int               m_x;
     
     abiwordContext( librdf_storage* storage,
-                    const char *name,
+                    const char * /*name*/,
                     librdf_hash* options )
-        : storage(storage)
-        , x(0)
+        : m_storage(storage)
+        , m_x(0)
     {
         librdf_storage_set_instance( storage, this );
 
         if(librdf_hash_get_as_boolean(options, "x")>0)
-            x = 1;
+            m_x = 1;
     }
 
     static abiwordContext* get( librdf_storage* storage )
     {
         if( !storage || !librdf_storage_get_instance(storage) )
         {
-            cerr << "problem getting abiwordContext from RDF storage!" << endl;
+            UT_DEBUGMSG(("problem getting abiwordContext from RDF storage!\n"));
             return 0;
         }
         
@@ -136,60 +135,72 @@ struct abiwordContext
         m_model = m;
     }
 
+#ifdef DEBUG
     void dump( const std::string& s )
     {
         m_model->dumpModel( s );
     }
+#endif
 };
 
 
 struct abiwordFindStreamContext
 {
-    librdf_storage*     storage;
-    abiwordContext*     context;
-    librdf_statement*   query;
-    librdf_statement*   statement;
-    librdf_node*        context_node;
+    librdf_storage*     m_storage;
+    abiwordContext*     m_context;
+    librdf_statement*   m_query;
+    librdf_statement*   m_statement;
+    librdf_node*        m_context_node;
     PD_RDFModelIterator m_iter;
-    bool done;
+    bool                m_done;
+    bool                m_queryIsSubjectOnly;
     
     abiwordFindStreamContext( librdf_storage* storage,
                               abiwordContext* c,
                               librdf_statement* statement,
                               librdf_node* context_node )
-        : storage( storage )
-        , context(c)
-        , done(false)
-        , query(0)
-        , statement(0)
-        , context_node(0)
+        : m_storage( storage )
+        , m_context(c)
+        , m_query(0)
+        , m_statement(0)
+        , m_context_node(0)
+        , m_done(false)
+        , m_queryIsSubjectOnly(false)
     {
-        librdf_storage_add_reference(this->storage);
+        librdf_storage_add_reference(m_storage);
         if( statement )
-            this->query = librdf_new_statement_from_statement( statement );
+            m_query = librdf_new_statement_from_statement( statement );
         if( context_node )
-            this->context_node = librdf_new_node_from_node( context_node );
+            m_context_node = librdf_new_node_from_node( context_node );
 
-        cerr << "abiwordFindStreamContext() query..." << endl;
-        cerr << "  subj:" << tostr( librdf_statement_get_subject( statement ) ) << endl;
-        cerr << "  pred:" << tostr( librdf_statement_get_predicate( statement ) ) << endl;
-        cerr << "   obj:" << tostr( librdf_statement_get_object( statement ) ) << endl;
+        xxx_UT_DEBUGMSG(("abiwordFindStreamContext() query...\n"));
+        xxx_UT_DEBUGMSG(("  subj: %s\n", tostr(librdf_statement_get_subject( statement )).c_str()));
+        xxx_UT_DEBUGMSG(("  pred: %s\n", tostr(librdf_statement_get_predicate( statement )).c_str()));
+        xxx_UT_DEBUGMSG(("   obj: %s\n", tostr(librdf_statement_get_object( statement )).c_str()));
+
+        if( m_query
+            &&  librdf_statement_get_subject( m_query )
+            && !librdf_statement_get_predicate( m_query )
+            && !librdf_statement_get_object( m_query ) )
+        {
+            m_queryIsSubjectOnly = true;
+        }
         
     }
 
     ~abiwordFindStreamContext()
     {
-        if(storage)
-            librdf_storage_remove_reference(storage);
+        if(m_storage)
+            librdf_storage_remove_reference(m_storage);
 
-        if(query)
-            librdf_free_statement(query);
+        if(m_query)
+            librdf_free_statement(m_query);
 
-        if(statement)
-            librdf_free_statement(statement);
+        if(m_statement)
+            librdf_free_statement(m_statement);
 
-        if(context_node)
-            librdf_free_node(context_node);
+        if(m_context_node)
+            librdf_free_node(m_context_node);
     }
     
 
@@ -201,45 +212,81 @@ struct abiwordFindStreamContext
 
     int getNext()
     {
-        cerr << "getNext() top..." << endl;
-        if(statement)
+        xxx_UT_DEBUGMSG(("getNext() top...\n"));
+        if(m_statement)
         {
-            librdf_free_statement(statement);
-            statement = 0;
+            librdf_free_statement(m_statement);
+            m_statement = 0;
         }
 
-        PD_RDFModelIterator e = context->m_model->end();
+        PD_RDFModelIterator e = m_context->m_model->end();
         if( m_iter == e )
         {
-            cerr << "getNext() hit end()" << endl;
-            done = 1;
+            xxx_UT_DEBUGMSG(("getNext() hit end()\n"));
+            m_done = 1;
             return -1;
         }
 
         for( ; m_iter != e; )
         {
-            PD_RDFStatement st = *m_iter;
-            ++m_iter;
-            cerr << "getNext() testing statement...st:" << st.toString() << endl;
+            PD_RDFStatement& st = *m_iter;
+            xxx_UT_DEBUGMSG(("getNext() testing statement...st: %s\n", st.toString().c_str()));
 
-            librdf_statement* stred = toRedland( st );
-            if( !query || librdf_statement_match( stred, query ) )
+            //
+            // Short cut evaluation for subj only queries
+            //
+            if( m_queryIsSubjectOnly )
             {
-                cerr << "getNext() statement matches..." << endl;
-                cerr << " st:" << st.toString() << endl;
-                statement = stred;
+                xxx_UT_DEBUGMSG(("getNext(qso) testing statement...st: %s\n", st.toString().c_str()));
+                if( st.getSubject().toString() != tostr(librdf_statement_get_subject( m_query )) )
+                {
+//                    m_iter = e;
+                    m_done = 1;
+                    xxx_UT_DEBUGMSG(("getNext(qso) DIFFERENT SUBJECT...\n" ));
+                    return -1;
+                }
+            }
+            
+            // if( m_queryIsSubjectOnly && !m_iter.moveToNextSubjectHavePOCol() )
+            // {
+            //     UT_DEBUGMSG(("getNext(qso) testing statement...st: %s\n", st.toString().c_str()));
+            //     if( st.getSubject().toString() == tostr(librdf_statement_get_subject( m_query )) )
+            //     {
+            //         if( m_iter.moveToNextSubjectHavePOCol() )
+            //             m_iter.moveToNextSubjectReadPO();
+            //         UT_DEBUGMSG(("getNext() matched statement...st: %s\n", st.toString().c_str()));
+            //         librdf_statement* stred = toRedland( *m_iter );
+            //         m_statement = stred;
+            //         break;
+            //     }
+                
+            //     UT_DEBUGMSG(("getNext() skipping statement...st: %s\n", st.toString().c_str()));
+            //     m_iter.moveToNextSubject();
+            //     continue;
+            // }
+
+            ++m_iter;
+            
+            librdf_statement* stred = toRedland( st );
+            if( !m_query || librdf_statement_match( stred, m_query ) )
+            {
+                xxx_UT_DEBUGMSG(("getNext() statement matches...\n"));
+                xxx_UT_DEBUGMSG((" st: %s\n", st.toString().c_str()));
+                m_statement = stred;
                 break;
             }
             librdf_free_statement( stred );
         }
         
+        xxx_UT_DEBUGMSG(("getNext() ret 0...\n"));
         return 0;
     }
     
 
-    void setup( librdf_world* world )
+    void setup( librdf_world* /*world*/ )
     {
-        cerr << "setup() top" << endl;
+//        static int counter = 0;
+        xxx_UT_DEBUGMSG(("setup() top c:%d\n", counter++ ));
 
         // {
         //     PD_RDFModelIterator iter = context->m_model->begin();
@@ -278,11 +325,29 @@ struct abiwordFindStreamContext
         // cerr << "setup() D............" << endl;
         
 
-        m_iter = context->m_model->begin();
-        PD_RDFModelIterator e = context->m_model->end();
-        cerr << "setup()...iter!=end:" << (m_iter != e) << endl;
+        m_iter = m_context->m_model->begin();
+        PD_RDFModelIterator e = m_context->m_model->end();
+//        UT_DEBUGMSG(("setup()...model.sz: %d\n", m_context->m_model->size() ));
+        xxx_UT_DEBUGMSG(("setup()...iter!=end: %d\n", (m_iter != e)));
+
+        if( m_queryIsSubjectOnly )
+        {
+            xxx_UT_DEBUGMSG(("setup(qso)...\n"));
+            for( ; m_iter != e ; )
+            {
+                PD_RDFStatement& st = *m_iter;
+                if( st.getSubject().toString() == tostr(librdf_statement_get_subject( m_query )) )
+                {
+                    m_iter.moveToNextSubjectReadPO();
+                    break;
+                }
+                m_iter.moveToNextSubject();
+            }
+        }
+        
+        
         PD_RDFStatement st = *m_iter;
-        cerr << "setup()...st1:" << st.toString() << endl;
+        xxx_UT_DEBUGMSG(("setup()...st1: %s\n", st.toString().c_str()));
     }
 };
 
@@ -315,7 +380,7 @@ abiword_storage_terminate(librdf_storage* storage)
 }
 
 static int
-abiword_storage_open(librdf_storage* storage, librdf_model* model)
+abiword_storage_open(librdf_storage* storage, librdf_model* /*model*/)
 {
     abiwordContext* c = abiwordContext::get( storage );
     return 0;
@@ -342,24 +407,24 @@ static int
 abiword_storage_find_statements_end_of_stream( void* context )
 {
     abiwordFindStreamContext* sc = abiwordFindStreamContext::get( context );
-    cerr << "abiword_storage_find_statements_end_of_stream() ctx:" << sc << " done:" << sc->done << endl;
+    xxx_UT_DEBUGMSG(("abiword_storage_find_statements_end_of_stream() ctx: %p done: %d\n", sc, sc->m_done));
     
-    if( sc->done )
+    if( sc->m_done )
         return 1;
   
-    if( !sc->statement )
+    if( !sc->m_statement )
         sc->getNext();
     
-    cerr << "abiword_storage_find_statements_end_of_stream(2) done:" << sc->done << endl;
-    return sc->done;
+    xxx_UT_DEBUGMSG(("abiword_storage_find_statements_end_of_stream(2) done: %d\n", sc->m_done));
+    return sc->m_done;
 }
 
 static int
 abiword_storage_find_statements_next_statement( void* context )
 {
     abiwordFindStreamContext* sc = abiwordFindStreamContext::get( context );
-    cerr << "abiword_storage_find_statements_next_statement() done:" << sc->done << endl;
-    if( sc->done )
+    xxx_UT_DEBUGMSG(("abiword_storage_find_statements_next_statement() done: %d\n", sc->m_done));
+    if( sc->m_done )
         return 1;
     return sc->getNext();
 }
@@ -368,16 +433,16 @@ static void*
 abiword_storage_find_statements_get_statement(void* context, int flags)
 {
     abiwordFindStreamContext* sc = abiwordFindStreamContext::get( context );
-    cerr << "abiword_storage_find_statements_get_statement() done:" << sc->done << " flags:" << flags << endl;
+    xxx_UT_DEBUGMSG(("abiword_storage_find_statements_get_statement() done: %d flags: %d\n", sc->m_done, flags));
 
     switch(flags)
     {
         case LIBRDF_ITERATOR_GET_METHOD_GET_OBJECT:
-            cerr << "get_statement() result...." << tostr( sc->statement ) << endl;
-            return sc->statement;
+            xxx_UT_DEBUGMSG(("get_statement() result.... %s\n", tostr(sc->m_statement).c_str()));
+            return sc->m_statement;
             
         default:
-            cerr << "ERROR: Unknown iterator method flag:" << flags << endl;
+            UT_DEBUGMSG(("ERROR: Unknown iterator method flag: %d\n", flags));
             return NULL;
     }
 }
@@ -388,7 +453,7 @@ abiword_storage_find_statements_finished(void* context)
 {
     abiwordFindStreamContext* sc = abiwordFindStreamContext::get( context );
     delete sc;
-    cerr << "=== abiword_storage_find_statements_finished()" << endl << endl;
+    xxx_UT_DEBUGMSG(("=== abiword_storage_find_statements_finished()\n"));
 }
 
 
@@ -397,14 +462,14 @@ abiword_storage_find_statements_with_context( librdf_storage* storage,
                                               librdf_statement* statement,
                                               librdf_node* context_node )
 {
-    cerr << "=== abiword_storage_find_statements()" << endl;
-    cerr << "statement:" << statement << endl;
+    xxx_UT_DEBUGMSG(("=== abiword_storage_find_statements()\n"));
+	xxx_UT_DEBUGMSG(("statement: %p\n", statement));
 
     if( statement )
     {
-        cerr << "subj:" << tostr( librdf_statement_get_subject( statement ) ) << endl;
-        cerr << "pred:" << tostr( librdf_statement_get_predicate( statement ) ) << endl;
-        cerr << " obj:" << tostr( librdf_statement_get_object( statement ) ) << endl;
+        xxx_UT_DEBUGMSG(("subj: %s\n", tostr(librdf_statement_get_subject( statement )).c_str()));
+        xxx_UT_DEBUGMSG(("pred: %s\n", tostr(librdf_statement_get_predicate( statement )).c_str()));
+        xxx_UT_DEBUGMSG((" obj: %s\n", tostr(librdf_statement_get_object( statement )).c_str()));
     }
     
     abiwordContext* c = abiwordContext::get( storage );
@@ -423,7 +488,7 @@ abiword_storage_find_statements_with_context( librdf_storage* storage,
         return NULL;
     }
     
-    cerr << "abiword_storage_find_statements(done)" << endl;
+    xxx_UT_DEBUGMSG(("abiword_storage_find_statements(done)\n"));
     return stream;  
 }
 
@@ -439,8 +504,8 @@ static int
 abiword_storage_contains_statement( librdf_storage* storage, 
                                     librdf_statement* query )
 {
+    xxx_UT_DEBUGMSG(("abiword_storage_contains_statement()\n"));
     abiwordContext* c = abiwordContext::get( storage );
-
     PD_RDFModelIterator iter = c->m_model->begin();
     PD_RDFModelIterator    e = c->m_model->end();
     
@@ -460,8 +525,8 @@ abiword_storage_contains_statement( librdf_storage* storage,
 
 static int
 abiword_storage_context_add_statement( librdf_storage* storage,
-                                       librdf_node* context_node,
-                                       librdf_statement* statement )
+                                       librdf_node* /*context_node*/,
+                                       librdf_statement* /*statement*/ )
 {
     // storage models are read-only and used for queries only.
     abiwordContext* c = abiwordContext::get( storage );
@@ -516,8 +581,8 @@ abiword_storage_serialise(librdf_storage* storage)
 
 void abiword_storage_factory( librdf_storage_factory* f )
 {
-    cerr << "abiword_storage_factory()" << endl;
-    cerr << "factory->name:" << f->name << endl;
+    xxx_UT_DEBUGMSG(("abiword_storage_factory()\n"));
+	xxx_UT_DEBUGMSG(("factory->name: %s\n", f->name));
 
     f->version               = LIBRDF_STORAGE_INTERFACE_VERSION;
     f->init                  = abiword_storage_init;
@@ -552,7 +617,7 @@ ensureStorageIsRegistered()
     {
         v = false;
     
-        int rc = librdf_storage_register_factory( getWorld(),
+        /*int rc = */librdf_storage_register_factory( getWorld(),
                                                   "abiword", "abiword",
                                                   abiword_storage_factory );
     }
@@ -570,20 +635,20 @@ static librdf_model* getRedlandModel( PD_RDFModelHandle abimodel )
     librdf_storage* storage = librdf_new_storage( getWorld(),
                                                   storage_name, name,
                                                   options_string );
-    cerr << "getRedlandModel() storage:" << storage << endl;
+    xxx_UT_DEBUGMSG(("getRedlandModel() storage: %p\n", storage));
     if( !storage )
     {
         return 0;
     }
     abiwordContext* ac = abiwordContext::get( storage );
     ac->setModel( abimodel );
-    cerr << "getRedlandModel(2) storage:" << storage << " abimodel:" << abimodel << endl;
+    xxx_UT_DEBUGMSG(("getRedlandModel(2) storage: %p abimodel: %p\n", storage, abimodel.get()));
     
     librdf_model* model = 0;
-    int rc = librdf_storage_open( storage, model );
+    /*int rc = */librdf_storage_open( storage, model );
     model = librdf_new_model( getWorld(), storage, NULL );
     
-    cerr << "getRedlandModel(3) storage:" << storage << " model:" << model << endl;
+    xxx_UT_DEBUGMSG(("getRedlandModel(3) storage: %p model: %p\n", storage, model));
     return model;
 }
 
@@ -617,7 +682,8 @@ PD_RDFQuery::executeQuery( const std::string& sparql_query_string )
     PD_ResultBindings_t ret;
 
 #ifndef WITH_REDLAND
-        return ret;
+	UT_UNUSED(sparql_query_string);
+	return ret;
 #else
         
     if( m_model->empty() )
@@ -645,7 +711,7 @@ PD_RDFQuery::executeQuery( const std::string& sparql_query_string )
     for( ; !librdf_query_results_finished( results );
          librdf_query_results_next( results ))
     {
-        cerr << "have query result, loop..." << endl;
+        xxx_UT_DEBUGMSG(("have query result, loop...\n"));
         
         std::map< std::string, std::string > x;
         const char ** names = 0;
@@ -653,18 +719,18 @@ PD_RDFQuery::executeQuery( const std::string& sparql_query_string )
         int bc = librdf_query_results_get_bindings_count( results );
         if( !bc )
             continue;
-        cerr << "have query result, bc:" << bc << endl;
+        xxx_UT_DEBUGMSG(("have query result, bc: %d\n", bc));
         
         values = (librdf_node**)calloc( bc+1, sizeof(librdf_node*));
         if( !librdf_query_results_get_bindings( results, &names, values ) )
         {
             const char * name  = names[0];
             librdf_node* value = values[0];
-            cerr << "initial  name:" << name << endl;
+            xxx_UT_DEBUGMSG(("initial  name: %s\n", name));
 
             for( int i = 0; name; ++i, name = names[i], value = values[i] )
             {
-                cerr << "i:" << i << " name:" << name << endl;
+                xxx_UT_DEBUGMSG(("i: %d name: %s\n"));
                 x.insert( make_pair( name, tostr( value )));
                 librdf_free_node( value );
             }
