@@ -29,6 +29,7 @@
 #include "ap_UnixLeftRuler.h"
 #include "xap_UnixApp.h"
 #include "xap_UnixDialogHelper.h"
+#include "xap_Gtk2Compat.h"
 #include "ap_UnixStatusBar.h"
 #include "ut_debugmsg.h"
 #include "ev_UnixMenuBar.h"
@@ -179,7 +180,9 @@ GtkWidget * AP_UnixFrameImpl::_createDocumentWindow()
 	m_hScroll = gtk_scrollbar_new(GTK_ORIENTATION_HORIZONTAL, m_pHadj);
 	g_object_set_data(G_OBJECT(m_pHadj), "user_data", this);
 	g_object_set_data(G_OBJECT(m_hScroll), "user_data", this);
+#if GTK_CHECK_VERSION(3,0,0)
 	gtk_widget_set_hexpand(m_hScroll, TRUE);
+#endif
 
 	m_iHScrollSignal = g_signal_connect(G_OBJECT(m_pHadj), "value_changed", G_CALLBACK(XAP_UnixFrameImpl::_fe::hScrollChanged), NULL);
 
@@ -187,7 +190,9 @@ GtkWidget * AP_UnixFrameImpl::_createDocumentWindow()
 	m_vScroll = gtk_scrollbar_new(GTK_ORIENTATION_VERTICAL, m_pVadj);
 	g_object_set_data(G_OBJECT(m_pVadj), "user_data", this);
 	g_object_set_data(G_OBJECT(m_vScroll), "user_data", this);
+#if GTK_CHECK_VERSION(3,0,0)
 	gtk_widget_set_vexpand(m_vScroll, TRUE);
+#endif
 
 	m_iVScrollSignal = g_signal_connect(G_OBJECT(m_pVadj), "value_changed", G_CALLBACK(XAP_UnixFrameImpl::_fe::vScrollChanged), NULL);
 
@@ -197,7 +202,9 @@ GtkWidget * AP_UnixFrameImpl::_createDocumentWindow()
 
 	// create a drawing area in the for our document window.
 	m_dArea = ap_DocView_new();
+#if GTK_CHECK_VERSION(3,0,0)
 	g_object_set(G_OBJECT(m_dArea), "expand", TRUE, NULL);
+#endif
 	g_object_set_data(G_OBJECT(m_dArea), "user_data", this);
 	UT_DEBUGMSG(("!!! drawing area m_dArea created! %p for %p \n",m_dArea,this));
 	gtk_widget_set_can_focus(m_dArea, true);	// allow it to be focussed
@@ -210,10 +217,16 @@ GtkWidget * AP_UnixFrameImpl::_createDocumentWindow()
 						    GDK_KEY_RELEASE_MASK |
 						    GDK_ENTER_NOTIFY_MASK |  
 						    GDK_FOCUS_CHANGE_MASK |
-						    GDK_LEAVE_NOTIFY_MASK));
+						    GDK_LEAVE_NOTIFY_MASK |
+						    GDK_SCROLL_MASK));
 	gtk_widget_set_double_buffered(GTK_WIDGET(m_dArea), FALSE);
+#if GTK_CHECK_VERSION(3,0,0)
 	g_signal_connect(G_OBJECT(m_dArea), "draw",
 					   G_CALLBACK(XAP_UnixFrameImpl::_fe::draw), NULL);
+#else
+	g_signal_connect(G_OBJECT(m_dArea), "expose_event",
+					   G_CALLBACK(XAP_UnixFrameImpl::_fe::expose), NULL);
+#endif
 
 	g_signal_connect(G_OBJECT(m_dArea), "key_press_event",
 					   G_CALLBACK(XAP_UnixFrameImpl::_fe::key_press_event), NULL);
@@ -249,8 +262,12 @@ GtkWidget * AP_UnixFrameImpl::_createDocumentWindow()
 
 	// create a table for scroll bars, rulers, and drawing area
 
+#if GTK_CHECK_VERSION(3,0,0)
 	m_grid = gtk_grid_new();
 	g_object_set(G_OBJECT(m_grid), "expand", TRUE, NULL);
+#else
+	m_grid = gtk_table_new(2, 1, FALSE); //was 1,1
+#endif
 	g_object_set_data(G_OBJECT(m_grid),"user_data", this);
 
 	// NOTE:  in order to display w/ and w/o rulers, gtk needs two tables to
@@ -265,6 +282,7 @@ GtkWidget * AP_UnixFrameImpl::_createDocumentWindow()
 		
 	// scroll bars
 	
+#if GTK_CHECK_VERSION(3,0,0)
 	gtk_grid_attach(GTK_GRID(m_grid), m_hScroll, 0, 1, 1, 1);
 
 	gtk_grid_attach(GTK_GRID(m_grid), m_vScroll, 1, 0, 1, 1);
@@ -288,7 +306,49 @@ GtkWidget * AP_UnixFrameImpl::_createDocumentWindow()
 	{
 		gtk_grid_attach(GTK_GRID(m_innergrid), m_dArea,   1, 1, 1, 1); 
 	}
+#else
+	gtk_table_attach(GTK_TABLE(m_grid), m_hScroll, 0, 1, 1, 2,
+					 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+					 (GtkAttachOptions) (GTK_FILL), // was just GTK_FILL
+					 0, 0);
 
+	gtk_table_attach(GTK_TABLE(m_grid), m_vScroll, 1, 2, 0, 1,
+					 (GtkAttachOptions) (GTK_FILL), // was just GTK_FILL
+					 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+					 0, 0);
+ 
+ 
+ 	// arrange the widgets within our inner table.
+	m_innergrid = gtk_table_new(2,2,FALSE);
+	gtk_table_attach( GTK_TABLE(m_grid), m_innergrid, 0, 1, 0, 1,
+						 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+						 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+						 0, 0); 
+	if ( bShowRulers )
+	{
+		gtk_table_attach(GTK_TABLE(m_innergrid), m_topRuler, 0, 2, 0, 1,
+						 (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
+						 (GtkAttachOptions)(GTK_FILL),
+						 0, 0);
+		if (m_leftRuler)
+			gtk_table_attach(GTK_TABLE(m_innergrid), m_leftRuler, 0, 1, 1, 2,
+							 (GtkAttachOptions)(GTK_FILL),
+							 (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
+							 0, 0);
+
+		gtk_table_attach(GTK_TABLE(m_innergrid), m_dArea,   1, 2, 1, 2,
+						 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+						 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+						 0, 0); 
+	}
+	else	// no rulers
+	{
+		gtk_table_attach(GTK_TABLE(m_innergrid), m_dArea,   1, 2, 1, 2,
+						 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+						 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+						 0, 0); 
+	}
+#endif
 	// create a 3d box and put the table in it, so that we
 	// get a sunken in look.
 	m_wSunkenBox = gtk_frame_new(NULL);
@@ -324,7 +384,7 @@ void AP_UnixFrameImpl::_setWindowIcon()
 	GtkWidget * window = getTopLevelWindow();
 
 	GtkIconTheme * theme = gtk_icon_theme_get_default();
-	GdkPixbuf * icon = gtk_icon_theme_load_icon(theme, "abiword_48", 48, GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
+	GdkPixbuf * icon = gtk_icon_theme_load_icon(theme, "abiword", 48, GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
 	if (icon)
 	{
 		gtk_window_set_icon (GTK_WINDOW (window), icon);
@@ -336,7 +396,7 @@ void AP_UnixFrameImpl::_setWindowIcon()
 	// are installed in a custom prefix, so let's try to load the icon manually.
 
 	GError* error = NULL;
-	std::string icon_path = std::string(DATADIR) + G_DIR_SEPARATOR_S + "icons" + G_DIR_SEPARATOR_S + "abiword_48.png";
+	std::string icon_path = std::string(ICONDIR) + G_DIR_SEPARATOR_S + "abiword.png";
 	icon = gdk_pixbuf_new_from_file(icon_path.c_str(), &error);
 	if (icon)
 	{
@@ -426,27 +486,45 @@ UT_RGBColor AP_UnixFrameImpl::getColorSelBackground () const
 
     UT_return_val_if_fail(m_dArea, UT_RGBColor(0,0,0));
     // owen says that any widget should be ok, not just text widgets
-	GtkStyleContext *pCtxt = gtk_widget_get_style_context(m_dArea);
-	GdkRGBA rgba;
-	gtk_style_context_get_background_color(pCtxt, GTK_STATE_FLAG_SELECTED, &rgba);
+#if GTK_CHECK_VERSION(3,0,0)
+    GtkStyleContext *pCtxt = gtk_widget_get_style_context(m_dArea);
+    GdkRGBA rgba;
+    gtk_style_context_get_background_color(pCtxt, GTK_STATE_FLAG_SELECTED, &rgba);
     return UT_RGBColor (rgba.red * 255, rgba.green * 255, rgba.blue * 255);
+#else
+    GdkColor clr = m_dArea->style->base[GTK_STATE_SELECTED];
+    return UT_RGBColor (clr.red >> 8, clr.green >> 8, clr.blue >> 8);
+#endif
 }
 
 UT_RGBColor AP_UnixFrameImpl::getColorSelForeground () const
 {
-	UT_return_val_if_fail(m_dArea, UT_RGBColor(0,0,0));
-
-	// owen says that any widget should be ok, not just text widgets
-	GtkStateFlags state;
-
-	// our text widget has focus
-	if (gtk_widget_has_focus(m_dArea))
-		state = GTK_STATE_FLAG_SELECTED;
-	else
-		state = GTK_STATE_FLAG_ACTIVE;
-
-	GtkStyleContext *pCtxt = gtk_widget_get_style_context(m_dArea);
-	GdkRGBA rgba;
-	gtk_style_context_get_color(pCtxt, state, &rgba);
-    return UT_RGBColor (rgba.red * 255, rgba.green * 255, rgba.blue * 255);
+  UT_return_val_if_fail(m_dArea, UT_RGBColor(0,0,0));
+  
+  // owen says that any widget should be ok, not just text widgets
+#if GTK_CHECK_VERSION(3,0,0)
+  GtkStateFlags state;
+  
+  // our text widget has focus
+  if (gtk_widget_has_focus(m_dArea))
+    state = GTK_STATE_FLAG_SELECTED;
+  else
+    state = GTK_STATE_FLAG_ACTIVE;
+  
+  GtkStyleContext *pCtxt = gtk_widget_get_style_context(m_dArea);
+  GdkRGBA rgba;
+  gtk_style_context_get_color(pCtxt, state, &rgba);
+  return UT_RGBColor (rgba.red * 255, rgba.green * 255, rgba.blue * 255);
+#else  
+  gint state;
+  
+  // our text widget has focus
+  if (GTK_WIDGET_HAS_FOCUS(m_dArea))
+    state = GTK_STATE_SELECTED;
+  else
+    state = GTK_STATE_ACTIVE;
+  
+  GdkColor clr = m_dArea->style->text[state];
+  return UT_RGBColor (clr.red >> 8, clr.green >> 8, clr.blue >> 8);
+#endif
 }
