@@ -319,6 +319,7 @@ AP_StatusBarField_ProgressBar::~AP_StatusBarField_ProgressBar(void)
 {
 }
 
+#if 0
 static void updateProgress(UT_Worker * pWorker)
 {
     UT_return_if_fail (pWorker);
@@ -330,6 +331,7 @@ static void updateProgress(UT_Worker * pWorker)
     if(pfspb->getListener())
 	pfspb->getListener()->notify();
 }
+#endif
 
 void AP_StatusBarField_ProgressBar::notify(AV_View * /*pView*/, const AV_ChangeMask /*mask*/)
 {
@@ -343,7 +345,8 @@ void AP_StatusBarField_ProgressBar::setStatusProgressType(int start, int end, in
     m_ProgressEnd = end;
     m_ProgressFlags = flags;
     m_ProgressStartPoint = 0;
-    /*
+
+#if 0
     DELETEP(m_ProgressTimer);
 
     if (m_ProgressStart == m_ProgressEnd &&
@@ -352,7 +355,7 @@ void AP_StatusBarField_ProgressBar::setStatusProgressType(int start, int end, in
 	m_ProgressTimer->stop();
 	m_ProgressTimer->set(50);	//Milliseconds
     }
-    */	
+#endif
 }
 
 void AP_StatusBarField_ProgressBar::setStatusProgressValue(int value)
