@@ -21,6 +21,7 @@
 
 #include "ie_imp_PasteListener.h"
 #include "pp_AttrProp.h"
+#include "pf_Frag.h"
 #include "pf_Frag_Strux.h"
 #include "px_CR_FmtMark.h"
 #include "px_CR_FmtMarkChange.h"
@@ -52,7 +53,7 @@ IE_Imp_PasteListener::IE_Imp_PasteListener(PD_Document * pDocToPaste, PT_DocPosi
 	m_pSourceDoc(pSourceDoc)
 {
 }	
-bool  IE_Imp_PasteListener::populate(PL_StruxFmtHandle /* sfh */,
+bool  IE_Imp_PasteListener::populate(fl_ContainerLayout* /* sfh */,
 					 const PX_ChangeRecord * pcr)
 {
 	PT_AttrPropIndex indexAP = pcr->getIndexAP();
@@ -105,9 +106,9 @@ bool  IE_Imp_PasteListener::populate(PL_StruxFmtHandle /* sfh */,
 	return true;
 }
 
-bool  IE_Imp_PasteListener::populateStrux(PL_StruxDocHandle /*sdh*/,
+bool  IE_Imp_PasteListener::populateStrux(pf_Frag_Strux* sdh,
 									  const PX_ChangeRecord * pcr,
-										  PL_StruxFmtHandle * /* psfh */)
+										  fl_ContainerLayout* * /* psfh */)
 {
 //
 // TODO graphics in struxes
@@ -141,8 +142,8 @@ bool  IE_Imp_PasteListener::populateStrux(PL_StruxDocHandle /*sdh*/,
 //
 // Now these can be found via the properties of the spans and strux's
 //
-            void *pHandle = NULL;
-            std::string mimeType;
+			PD_DataItemHandle pHandle = NULL;
+			std::string mimeType;
 			const char * szName= NULL;
 			const UT_ByteBuf * pBuf = NULL;
 			UT_sint32 k = 0;
@@ -152,6 +153,13 @@ bool  IE_Imp_PasteListener::populateStrux(PL_StruxDocHandle /*sdh*/,
 				k++;
 			}
 			m_bFirstSection = false;
+			if (sdh->getNext() && (sdh->getNext()->getType() == pf_Frag::PFT_Strux) &&
+			    (static_cast<pf_Frag_Strux*>(sdh->getNext())->getStruxType() != PTX_Block))
+			{
+			    // The second frag is not a PXT_Block (it is probably a PTX_SectionTable)
+			    // The first block encountered needs to be inserted in the piece table
+			    m_bFirstBlock = false;
+			}
 			return true;
 		}
 		//
