@@ -1,20 +1,20 @@
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * Copyright (C) 2003 Martin Sevior
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
 
@@ -48,25 +48,25 @@ class ABI_EXPORT IE_Imp_PasteListener: public PL_Listener
 public:
 	IE_Imp_PasteListener(PD_Document * pDocToPaste, PT_DocPosition insPoint, PD_Document * pSourceDoc);
 	virtual ~IE_Imp_PasteListener(){}
-	
-	virtual bool		populate(PL_StruxFmtHandle sfh,
+
+	virtual bool		populate(fl_ContainerLayout* sfh,
 								 const PX_ChangeRecord * pcr);
 
-	virtual bool		populateStrux(PL_StruxDocHandle sdh,
+	virtual bool		populateStrux(pf_Frag_Strux* sdh,
 									  const PX_ChangeRecord * pcr,
-									  PL_StruxFmtHandle * psfh);
+									  fl_ContainerLayout* * psfh);
 
-	virtual bool		change(PL_StruxFmtHandle /*sfh*/,
+	virtual bool		change(fl_ContainerLayout* /*sfh*/,
 							   const PX_ChangeRecord * /*pcr*/)
 		{return true;}
 
-	virtual bool		insertStrux(PL_StruxFmtHandle /*sfh*/,
+	virtual bool		insertStrux(fl_ContainerLayout* /*sfh*/,
 									const PX_ChangeRecord * /*pcr*/,
-									PL_StruxDocHandle /*sdhNew*/,
+									pf_Frag_Strux* /*sdhNew*/,
 									PL_ListenerId /*lid*/,
-									void (* /*pfnBindHandles*/)(PL_StruxDocHandle sdhNew,
+									void (* /*pfnBindHandles*/)(pf_Frag_Strux* sdhNew,
 															PL_ListenerId lid,
-															PL_StruxFmtHandle sfhNew))
+															fl_ContainerLayout* sfhNew))
 		{ return true;}
 
 	virtual bool		signal(UT_uint32 /*iSignal*/)
