@@ -21,6 +21,8 @@
 #include "tf_test.h"
 #include "xap_App.h"
 
+#include "all_test.h"
+
 
 #ifndef ABI_BUILD_ID
 #define ABI_BUILD_ID            "unknown"
@@ -39,15 +41,6 @@
 #endif /* ABI_BUILD_TARGET */
 
 
-#ifndef WITH_GNOMEUI
-// work around a linker bug. see bugzilla 8286
-extern unsigned char g_pngSidebar[];
-
-unsigned char *foo1 = g_pngSidebar;
-#endif
-
-
-
 const char* XAP_App::s_szBuild_ID = "TEST";
 const char* XAP_App::s_szAbiSuite_Home = "/tmp";
 const char* XAP_App::s_szBuild_Version = "TEST";
